@@ -12,11 +12,12 @@ mtan_enc : MTAN encoder
 
 Functions
 ---------
-default_regressor : default top regressor when not provided
-default_classifier : default top classifier when not provided
+default_regressor : default top regressor when not provided in `mtan_enc`
+default_classifier : default top classifier when not provided in `mtan_enc`
 """
 
 def default_regressor(nhidden):
+    """default top regressor when not provided in `mtan_enc`"""
     return nn.Sequential(
         nn.Linear(nhidden, 150),
         nn.ReLU(),
@@ -25,6 +26,7 @@ def default_regressor(nhidden):
         nn.Linear(150, 1))
 
 def default_classifier(n_out, nhidden):
+    """default top classifier when not provided in `mtan_enc`"""
     return nn.Sequential(
         nn.Linear(nhidden, 150),
         nn.ReLU(),
@@ -175,4 +177,4 @@ class mtan_enc(nn.Module):
         out = self.att(query, key, x, mask)
         out = out.permute(1, 0, 2)
         _, out = self.enc(out)
-        return self.model(out.squeeze(0)).squeeze() if not encode_ts else out
\ No newline at end of file
+        return self.model(out.squeeze(0)) if not encode_ts else out
\ No newline at end of file
