@@ -318,10 +318,9 @@ class mtse:
             for train_batch, label in self.train_loader:
                 train_batch, label = train_batch.to(self.device), label.to(self.device) 
                 batch_len  = train_batch.shape[0]
-                if self.model_type == 'regression':
-                    out = self.ts_encoder(train_batch[:, :, :self.n_ts*2], train_batch[:, :, -1])
-                else:
-                    out = self.ts_encoder(train_batch[:, :, :self.n_ts*2], train_batch[:, :, -1]).reshape(-1 ,1)
+                out = self.ts_encoder(train_batch[:, :, :self.n_ts*2], train_batch[:, :, -1])  
+                print(out)
+                print(out.shape)                  
                 loss = criterion(out, label)
                 train_loss += loss.item() * batch_len
                 train_n += batch_len
